gchecky.controller

Package gchecky :: Module controller |
[hide private]
[frames] | no frames]

# Module controller

source code

Classes | [hide private]
| ProcessingException
| html_order TODO:
| ControllerLevel_1
| ControllerContext
| GcheckyError Base class for exception that could be thrown by gchecky library.
| DataError An exception of this class occures whenever there is error in converting python data to/from xml.
| HandlerError An exception of this class occures whenever an exception is thrown from user defined handler.
| SystemError An exception of this class occures whenever there is a system error, such as network being unavailable or DB down.
| LibraryError An exception of this class occures whenever there is a bug encountered in gchecky library.
| ControllerLevel_2
| Controller